[Commits] r1543 - sandbox/cmoullet/ux/GoogleEarthPanel/ux/widgets

commits at geoext.org commits at geoext.org
Thu Dec 3 06:49:34 CET 2009


Author: cmoullet
Date: 2009-12-03 06:49:34 +0100 (Thu, 03 Dec 2009)
New Revision: 1543

Modified:
   sandbox/cmoullet/ux/GoogleEarthPanel/ux/widgets/GoogleEarthPanel.js
Log:
Move 3D with onmoveend event, not on move


Modified: sandbox/cmoullet/ux/GoogleEarthPanel/ux/widgets/GoogleEarthPanel.js
===================================================================
--- sandbox/cmoullet/ux/GoogleEarthPanel/ux/widgets/GoogleEarthPanel.js	2009-12-03 05:42:21 UTC (rev 1542)
+++ sandbox/cmoullet/ux/GoogleEarthPanel/ux/widgets/GoogleEarthPanel.js	2009-12-03 05:49:34 UTC (rev 1543)
@@ -207,7 +207,7 @@
         // Refreshes GE on map move
         if (this.map && this.navigationModeFrom2D) {
             this.map.events.on({
-                move: this.onMove,
+                moveend: this.onMoveEnd,
                 scope: this
             });
         }
@@ -322,7 +322,7 @@
         }
         if (this.map && this.navigationModeFrom2D) {
             this.map.events.un({
-                move: this.onMove,
+                move: this.onMoveEnd,
                 scope: this
             });
         }
@@ -333,10 +333,10 @@
         GeoExt.ux.GoogleEarthPanel.superclass.beforeDestroy.apply(this, arguments);
     },
     /**
      * Function onMove
      * Changes GE position on 2D map move
      */
-    onMove: function() {
+    onMoveEnd: function() {
         this.lookTo(this.map.getCenter());
     },
 
@@ -333,10 +333,10 @@
     },
     /**
-     * Function onMove
-     * Changes GE position on 2D map move
+     * Function onMoveEnd
+     * Changes GE position after 2D map move
      */



More information about the Commits mailing list